@@ -208,13 +208,15 @@ def deploy_remote_core():
     # Call pre-install script
     run_hooked_actions('PRE_INSTALL_ACTIONS')
 
-    # Add this app to server (maybe this is the first-time deploy)
-    run('bsjack server.add_app:%s' % project_name)
+    # Create this app to server
+    run('bsjack server.create_app:%s' % project_name)
 
     # Send code
+    pass
 
     # Update this app in server
     run('bsjack server.update_app:%s' % project_name)
 
     # Call post-install script
     run_hooked_actions('POST_INSTALL_ACTIONS')
+
