@@ -1,6 +1,7 @@
 import os
 from fabric.api import *
 from fabric.colors import *
+from fabric.contrib.console import confirm
 from soil.fabric import eval_kwargs
 from soil.filesystem import temporary_directory
 from beanstalk import IDENTIFIER
@@ -100,6 +101,7 @@ def setup(settings_path=None, **settings_patches):
     # Create homebase
     print section_title('Deploy target is: %s' % beanstalk_stack_base)
     local('mkdir -p %s' % beanstalk_stack_base)
+    local('mkdir -p %s' % os.path.join(beanstalk_stack_base, 'global-logs'))
     local('chmod o+rx %s' % beanstalk_stack_base)
     local('chown beanstalk:beanstalk %s' % beanstalk_stack_base)
 
@@ -116,23 +118,48 @@ def create_app(project_name, settings_path=None, **settings_patches):
     remote_project_base = os.path.abspath(os.path.join(beanstalk_stack_base, project_name))
     remote_project_source = os.path.join(remote_project_base, 'source/')
     remote_project_logs = os.path.join(remote_project_base, 'logs/')
-    remote_project_venv = os.path.join(remote_project_base, 'venv/')
+    #remote_project_venv = os.path.join(remote_project_base, 'venv/')
 
     if os.path.exists(remote_project_base):
         return
 
     # Create folders
+    print section_title('Create folders')
     local('mkdir -p %s' % remote_project_base)
     local('mkdir -p %s' % remote_project_source)
     local('mkdir -p %s' % remote_project_logs)
 
     # Initialize venv
+    print section_title('Initialize virtual env')
     with lcd(remote_project_base):
         local('virtualenv venv')
 
     # Initialize git
+    print section_title('Make git repository')
     with lcd(remote_project_source):
         local('git init')
+        local('touch .gitignore')
+        local('git add .gitignore')
+        local('git commit -m "Init commit"')
+
+
+@task
+@beanstalk_role('derver')
+def delete_app(project_name, settings_path=None, **settings_patches):
+    settings_patches = eval_kwargs(settings_patches)
+    beanstalk_settings = load_beanstalk_settings(local_settings_path=settings_path, **settings_patches)
+    beanstalk_stack_base = beanstalk_settings['BEANSTALK_STACK_BASE']
+    set_verbose_level()
+
+    # Folder paths
+    remote_project_base = os.path.abspath(os.path.join(beanstalk_stack_base, project_name))
+
+    remove = confirm('Remove project: %s ?' % project_name, default=False)
+
+    # delete
+    if remove:
+        print 'Remove app @ %s' % remote_project_base
+        local('rm -rf %s' % remote_project_base)
 
 
 @task
